from django.core.exceptions import ImproperlyConfigured
from django.db.models.fields.related_descriptors import ReverseOneToOneDescriptor, ReverseManyToOneDescriptor
from django.db.models.fields.reverse_related import ForeignObjectRel
from django.urls import reverse

class OnSuccessMixin():
    on_success = None
    drop_key = None
    kwarg_override=None

    def get_success_url(self):
        """Return the URL to redirect to after processing."""
        if not self.on_success:
            raise ImproperlyConfigured("No name to redirect to. Provide a on_success.")

        match = self.request.resolver_match
        kwargs = match.kwargs
        if self.kwarg_override is not None:
            kwargs.update(self.kwarg_override)
        namespaces = match.namespaces

        if self.drop_key is not None and self.drop_key in kwargs:
            del kwargs[self.drop_key]

        return reverse(
            ':'.join(namespaces + [self.on_success]),
            kwargs=kwargs,
        )
