# Generated by Django 4.0.4 on 2022-05-23 14:09

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.expressions


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('first_name', models.CharField(max_length=150, verbose_name='first name')),
                ('last_name', models.CharField(blank=True, max_length=150, verbose_name='last name')),
                ('email', models.EmailField(max_length=254, unique=True, verbose_name='email address')),
                ('is_accountant', models.BooleanField(default=False, help_text='Designates whether the user can access features reserved for accounting.', verbose_name='accountant status')),
                ('is_active', models.BooleanField(default=True, help_text='Designates whether this user should be treated as active. Unselect this instead of deleting accounts.', verbose_name='active')),
            ],
            options={
                'verbose_name': 'user',
                'verbose_name_plural': 'users',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Announcement',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('message', models.TextField(help_text='Long messages may negativly impact overall website usabillity.', verbose_name='message')),
                ('is_active', models.BooleanField(default=False, verbose_name='active')),
            ],
            options={
                'verbose_name': 'announcement',
                'verbose_name_plural': 'announcements',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Department',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='name')),
                ('accounting_entry', models.CharField(max_length=7, unique=True, verbose_name='accounting entry')),
            ],
            options={
                'verbose_name': 'department',
                'verbose_name_plural': 'departments',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='NewUser',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('token', models.SlugField(unique=True, verbose_name='token')),
                ('expiration_date', models.DateField(help_text='Date after which the generated token will be expired.', verbose_name='expiration date')),
            ],
            options={
                'verbose_name': 'new user',
                'verbose_name_plural': 'new users',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Period',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.DateField(verbose_name='start date')),
                ('end', models.DateField(verbose_name='end date')),
                ('dead_line', models.DateTimeField(verbose_name='dead line')),
                ('dead_line_final', models.DateTimeField(verbose_name='final dead line')),
            ],
            options={
                'verbose_name': 'period',
                'verbose_name_plural': 'periods',
                'get_latest_by': 'start',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('invoice_number', models.IntegerField(help_text='Identifier for invoice as number between 20000000 and 39999999.', unique=True, validators=[django.core.validators.MinValueValidator(20000000), django.core.validators.MaxValueValidator(39999999)], verbose_name='invoice number')),
                ('name', models.CharField(max_length=255, verbose_name='name')),
                ('contractor', models.CharField(max_length=255, verbose_name='contractor')),
                ('start', models.DateField(verbose_name='start date')),
                ('end', models.DateField(verbose_name='end date')),
                ('department', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='vkk.department')),
            ],
            options={
                'verbose_name': 'project',
                'verbose_name_plural': 'projects',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='ProjectAssignment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('contributor', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='contributor')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='vkk.project', verbose_name='project')),
            ],
            options={
                'verbose_name': 'project assignment',
                'verbose_name_plural': 'project assignments',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='SalaryLevel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('salary_code', models.CharField(max_length=15, unique=True, verbose_name='salary code')),
            ],
            options={
                'verbose_name': 'salary level',
                'verbose_name_plural': 'salary levels',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='WorkHoursCorrection',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ammount', models.DecimalField(decimal_places=2, help_text='Ammount by which the total number of workhoursfor a given project assignment and period should be corrected.', max_digits=5)),
                ('period', models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, to='vkk.period', verbose_name='period')),
                ('project_assignment', models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, to='vkk.projectassignment', verbose_name='project assignment')),
            ],
            options={
                'verbose_name': 'work hours correction',
                'verbose_name_plural': 'work hours correction',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='WorkHours',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('day', models.DateField(help_text='Date of work day.', verbose_name='work day')),
                ('hours', models.DecimalField(decimal_places=2, help_text='Number of hours worked with precision up to two decimal places.', max_digits=4, validators=[django.core.validators.MinValueValidator(0.01), django.core.validators.MaxValueValidator(24)], verbose_name='work hours')),
                ('period', models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, to='vkk.period', verbose_name='period')),
                ('project_assignment', models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, to='vkk.projectassignment', verbose_name='project assignment')),
            ],
            options={
                'verbose_name': 'work hours',
                'verbose_name_plural': 'work hours',
                'default_permissions': (),
            },
        ),
        migrations.CreateModel(
            name='ProjectManager',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.DateField(verbose_name='start date')),
                ('end', models.DateField(verbose_name='end date')),
                ('is_proxy', models.BooleanField(default=False, help_text='Designates whether management rights are given to the userfor administrative uses only.', verbose_name='proxy')),
                ('manager', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='manager')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='vkk.project', verbose_name='project')),
            ],
            options={
                'verbose_name': 'project manager',
                'verbose_name_plural': 'project managers',
                'default_permissions': (),
            },
        ),
        migrations.AddField(
            model_name='projectassignment',
            name='salary_level',
            field=models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, to='vkk.salarylevel', verbose_name='salary level'),
        ),
        migrations.CreateModel(
            name='PeriodClosure',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_closed', models.BooleanField(default=False, verbose_name='closed')),
                ('period', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='vkk.period', verbose_name='period')),
                ('project_assignment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='vkk.projectassignment', verbose_name='project assignment')),
            ],
            options={
                'verbose_name': 'period',
                'verbose_name_plural': 'periods',
                'default_permissions': (),
            },
        ),
        migrations.AddConstraint(
            model_name='period',
            constraint=models.CheckConstraint(check=models.Q(('start__lte', django.db.models.expressions.F('end'))), name='runtime_check_period'),
        ),
        migrations.AddConstraint(
            model_name='period',
            constraint=models.CheckConstraint(check=models.Q(('end__lte', django.db.models.expressions.F('dead_line'))), name='dead_line_check_period'),
        ),
        migrations.AddConstraint(
            model_name='period',
            constraint=models.CheckConstraint(check=models.Q(('dead_line__lte', django.db.models.expressions.F('dead_line_final'))), name='dead_line_final_check_period'),
        ),
        migrations.AddField(
            model_name='newuser',
            name='user',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='user'),
        ),
        migrations.AddConstraint(
            model_name='workhourscorrection',
            constraint=models.UniqueConstraint(fields=('project_assignment', 'period'), name='unique_constraint_work_hours_correction'),
        ),
        migrations.AddConstraint(
            model_name='workhours',
            constraint=models.UniqueConstraint(fields=('project_assignment', 'day'), name='unique_constraint_work_hours'),
        ),
        migrations.AddConstraint(
            model_name='workhours',
            constraint=models.CheckConstraint(check=models.Q(('hours__gt', 0.0)), name='min_work_hours'),
        ),
        migrations.AddConstraint(
            model_name='workhours',
            constraint=models.CheckConstraint(check=models.Q(('hours__lte', 24.0)), name='max_work_hours'),
        ),
        migrations.AddConstraint(
            model_name='projectmanager',
            constraint=models.CheckConstraint(check=models.Q(('start__lte', django.db.models.expressions.F('end'))), name='runtime_check_manager'),
        ),
        migrations.AddConstraint(
            model_name='projectmanager',
            constraint=models.UniqueConstraint(fields=('manager', 'project'), name='unique_constraint_project_manager'),
        ),
        migrations.AddConstraint(
            model_name='projectassignment',
            constraint=models.UniqueConstraint(fields=('contributor', 'salary_level', 'project'), name='unique_constraint_project_assignment'),
        ),
        migrations.AddConstraint(
            model_name='project',
            constraint=models.CheckConstraint(check=models.Q(('start__lte', django.db.models.expressions.F('end'))), name='runtime_check_projekt'),
        ),
        migrations.AddConstraint(
            model_name='project',
            constraint=models.CheckConstraint(check=models.Q(('invoice_number__gte', 20000000), ('invoice_number__lte', 39999999)), name='invoice_number_intervall_check'),
        ),
        migrations.AddConstraint(
            model_name='periodclosure',
            constraint=models.UniqueConstraint(fields=('period', 'project_assignment'), name='unique_constraint_period_closure'),
        ),
    ]
