from django.contrib.auth.forms import SetPasswordForm
from django.forms import ModelForm, CharField, PasswordInput
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _
from .models import User

class ConfirmNewUserForm(SetPasswordForm, ModelForm):
    class Meta:
        model = User
        fields = ['first_name', 'last_name']

    def __init__(self, *args, **kwargs):
        kwargs.update({'user': kwargs['instance']})
        super().__init__(*args, **kwargs)
    
    def save(self, commit=True):
        instance = super().save(commit)
        instance.is_active = True
        if commit:
            instance.save()
        return instance

class UserDetailsChangeForm(ModelForm):
    class Meta:
        model = User
        fields = ['first_name', 'last_name']
    
    error_messages = {
        'password_incorrect': _("Your password was entered incorrectly. Please enter it again."),
    }
    password = CharField(
        label=_("Password"),
        strip=False,
        widget=PasswordInput(attrs={'autocomplete': 'current-password', 'autofocus': True}),
        help_text=_('Please enter your password to confirm any changes made.')
    )

    def clean_password(self):
        password = self.cleaned_data["password"]
        if not self.instance.check_password(password):
            raise ValidationError(
                self.error_messages['password_incorrect'],
                code='password_incorrect',
            )
        return password
