from django.shortcuts import redirect
from django.urls import reverse_lazy
from django.views.generic import FormView, TemplateView
from django.core.signing import Signer, BadSignature
from django.contrib.auth.mixins import LoginRequiredMixin
from .models import SALT, NewUser
from .forms import ConfirmNewUserForm, UserDetailsChangeForm

class RegistrationConfirmView(FormView):
    template_name = 'vkk/users/registration_confirm.html'
    form_class = ConfirmNewUserForm
    success_url = reverse_lazy('vkk:users:registration_confirm_done')

    def setup(self, request, *args, **kwargs):
        super().setup(request, *args, **kwargs)
        try:
            token = Signer(sep='/', salt=SALT).unsign(
                '/'.join([kwargs['token'], kwargs['signature']])
            )
            self.new_user = NewUser.objects.get(token=token)
            self.is_link_valid = True
        except (BadSignature, NewUser.DoesNotExist):
            self.is_link_valid = False

    def dispatch(self, request, *args, **kwargs):
        if not self.is_link_valid:
            return redirect('vkk:users:invalid_registration')
        else:
            return super().dispatch(request, *args, **kwargs)

    def get_form_kwargs(self):
        kwargs = super().get_form_kwargs()
        kwargs.update({'instance': self.new_user.user})
        return kwargs

    def form_valid(self, form):
        form.save()
        self.new_user.delete()
        return super().form_valid(form)

class UserDetailsChangeView(LoginRequiredMixin, FormView):
    template_name = 'vkk/users/user_details_change.html'
    form_class = UserDetailsChangeForm

    def get_form_kwargs(self):
        kwargs = super().get_form_kwargs()
        kwargs.update({'instance': self.request.user})
        return kwargs

    def form_valid(self, form):
        form.save()
        return super().form_valid(form)

class UserDetailsChangeSuccessView(LoginRequiredMixin, TemplateView):
    template_name = 'vkk/users/user_details_change_done.html'
