from django.urls import path, include
from django.utils.translation import gettext_lazy as _
from django.forms import modelform_factory
from vkk.generic.forms import CustomDateInput
from vkk.models import GeneralCosts
from vkk.workhours.accounting.views import (
    AccountingCreateView, AccountingUpdateView,
    AccountingDeleteView, AccountingListView,
    AccountingSuccessView
)

model = {'model': GeneralCosts}
form_class = modelform_factory(
    model=GeneralCosts,
    fields=['start', 'costs'],
    widgets={'start':CustomDateInput}
)

app_name = 'general'
urlpatterns = [
    path(
        _('create/'),
        AccountingCreateView.as_view(**model, form_class=form_class),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:pk>/update/'),
        AccountingUpdateView.as_view(**model, form_class=form_class),
        name='update'
    ),
    path(
        _('update/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/update_success.html',
            **model
        ),
        name='update_success'
    ),
    path(
        _('<int:pk>/delete/'),
        AccountingDeleteView.as_view(**model),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model
        ),
        name='delete_success'
    ),
    path(
        '',
        AccountingListView.as_view(
            **model,
            fields=['start', 'costs'],
            ordering=['start'],
        ),
        name='default'
    ),
]