from smtplib import SMTPException
from django import forms
from django.core.mail import send_mail
from django.utils.translation import gettext_lazy as _
from vkk.models import User, ProjectManager

MAILING_CHOICES = [
    ('0', _('All Users')),
    ('1', _('Project Managers')),
    ('2', _('Accountants'))
]

class MailingListForm(forms.Form):
    mailing_list = forms.ChoiceField(label=_('Mailing List'), choices=MAILING_CHOICES)
    subject = forms.CharField(label=_('Subject'), max_length=255, empty_value=True)
    message = forms.CharField(label=_('Message'), max_length=16383, widget=forms.Textarea())
    
    def send_mail(self):
        if not self.is_valid():
            return

        mailing_list = self.cleaned_data["mailing_list"]
        email_addresses = None
        if mailing_list == '0':
            email_addresses = list(
                User.objects.filter(
                    is_active=True
                ).values_list('email', flat=True)
            )
        elif mailing_list == '1':
            email_addresses = list(
                    ProjectManager.objects.filter(
                    manager__is_active=True,
                ).values_list('manager__email', flat=True)
                )
        elif mailing_list == '2':
            email_addresses = list(
                    User.objects.filter(
                    is_active=True,
                    is_accountant=True,
                ).values_list('email', flat=True)
            )
        
        try:
            send_mail(
                subject=self.cleaned_data["subject"],
                message=self.cleaned_data["message"],
                from_email=None,
                recipient_list=email_addresses
            )
        except SMTPException:
            raise

        return
        