from django.forms import ModelForm
from datetime import date, timedelta
from vkk.generic.forms import CustomDateInput
from vkk.users.models import NewUser, send_renew_mail

class NewUserRenewForm(ModelForm):
    class Meta:
        model = NewUser
        fields = ['expiration_date']
        widgets = {'expiration_date' : CustomDateInput}
    
    def __init__(self, *args, **kwargs):
        if ( kwargs.get('initial') is None 
            or kwargs['initial'].get('expiration_date') is None ):
            kwargs['initial'] = {
                'expiration_date' : date.today() + timedelta(days=21)
            }
        super().__init__(*args, **kwargs)

    def save(self, commit=True):
        send_renew_mail(self.instance)
        return super().save(commit)
