from django.urls import path
from django.utils.translation import gettext_lazy as _
from django.forms import modelform_factory
from ..views import *
from .views import AccountingPeriodDetailView, AccountingPeriodDetailDepartmentView
from vkk.workhours.models import Period
from vkk.generic.forms import CustomDateInput, CustomDateTimeInput

model = {'model': Period}
fields = {'fields': ['start', 'end', 'dead_line', 'dead_line_final']}
form_class = {'form_class': modelform_factory(**model, **fields,
                                              widgets={
                                                  'start': CustomDateInput,
                                                  'end':  CustomDateInput,
                                                  'dead_line': CustomDateTimeInput,
                                                  'dead_line_final': CustomDateTimeInput
                                              })
              }
action_options = {
    'action_options': {
        'details': _('Details'),
        'update': _('Update'),
        'delete': _('Delete'),
    }
}

app_name = 'periods'
urlpatterns = [
    path(
        _('<int:pk>/details/'),
        AccountingPeriodDetailView.as_view(),
        name='details'
    ),
    path(
        _('<int:pk>/details/projects_open_by_department/<int:department_pk>'),
        AccountingPeriodDetailDepartmentView.as_view(),
        name='projects_open'
    ),
    path(
        _('create/'),
        AccountingCreateView.as_view(**model, **form_class),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:pk>/update/'),
        AccountingUpdateView.as_view(**model, **form_class),
        name='update'
    ),
    path(
        _('update/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/update_success.html',
            **model
        ),
        name='update_success'
    ),
    path(
        _('<int:pk>/delete/'),
        AccountingDeleteView.as_view(**model),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model
        ),
        name='delete_success'
    ),
    path(
        '',
        AccountingListView.as_view(
            **model,
            **fields,
            ordering=['start'],
            **action_options
        ),
        name='default'
    ),
]
