from django.db.models import Count, Q
from django.shortcuts import get_object_or_404
from vkk.workhours.accounting.views import AccountingDetailView
from vkk.workhours.models import Period, Project, Department


class AccountingPeriodDetailView(AccountingDetailView):
    model = Period
    fields = ['start', 'end', 'dead_line', 'dead_line_final']
    template_name = "vkk/workhours/accounting/period/details.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        # projects = Project.objects.exclude(
        #     projectassignment__periodclosure__period=kwargs["object"],
        #     projectassignment__periodclosure__is_closed_contributor=True,
        #     projectassignment__periodclosure__is_closed_manager=True,
        # ).filter(
        #     projectassignment__isnull=False
        # )
        projects = Project.objects.exclude(
            Q(projectassignment__isnull=True) | Q(projectassignment__periodclosure__period=kwargs["object"]) & Q(
                projectassignment__periodclosure__is_closed_contributor=True) & Q(projectassignment__periodclosure__is_closed_manager=True)
        ).values(
            'department', 'department__name', 'department__pk'
        ).annotate(
            projects_not_closed=Count('department')
        ).exclude(department=None).order_by('department__name')
        context["projects"] = projects
        return context


class AccountingPeriodDetailDepartmentView(AccountingDetailView):
    model = Period
    fields = ['start', 'end', 'dead_line', 'dead_line_final']
    template_name = "vkk/workhours/accounting/period/projects.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        department = get_object_or_404(
            Department, pk=self.kwargs["department_pk"])
        projects = Project.objects.exclude(
            Q(projectassignment__isnull=True) | Q(projectassignment__periodclosure__period=kwargs["object"]) & Q(
                projectassignment__periodclosure__is_closed_contributor=True) & Q(projectassignment__periodclosure__is_closed_manager=True)
        ).filter(
            department=department,
        )
        context["department"] = department
        context["projects"] = projects
        return context
