from django import forms
from vkk.workhours.models import (
    ProjectFundedStaff, ProjectFundedStaffDate, SalaryLevel,
    Project
)
from vkk.workhours.forms import CustomDateInput

class ProjectFundedStaffForm(forms.ModelForm):
    class Meta:
        model = ProjectFundedStaffDate
        fields = ['date']
        widgets = {
            'date': CustomDateInput(),
        }
    
    def __init__(self, *args, invoice_number=None, **kwargs):
        super().__init__(*args, **kwargs)
        self._invoice_number = invoice_number

        # Collect all salary levels to create Fields
        self._salary_levels = SalaryLevel.objects.all()
        field_class = ProjectFundedStaff.hours.field.formfield
        for salary_level in self._salary_levels:
            self.fields[
                'fun_' + str(salary_level.salary_code)
            ] = field_class(
                label=salary_level.salary_code
            )
        # Look for model instance and fill associated fields accordingly
        if self.instance is not None:
            project_funded_staff_instances = ProjectFundedStaff.objects.filter(
                start=self.instance
            ).select_related('salary_level')
            for project_funded_staff_instance in project_funded_staff_instances:
                self.fields[
                    'fun_' + str(project_funded_staff_instance.salary_level.salary_code)
                ].initial = project_funded_staff_instance.hours
    
    def save(self, commit=True):
        if self.instance.pk is None:
            self.instance.project = Project.objects.get(invoice_number=self._invoice_number)
        # save instance
        super().save(commit)
        # save all associated instances
        if self.is_valid() and self.has_changed():
            project_funded_staff_list = []
            for salary_level in self._salary_levels:
                hours = self.cleaned_data.get('fun_' + str(salary_level.salary_code))
                project_funded_staff_list.append(
                    ProjectFundedStaff(
                        salary_level=salary_level,
                        start=self.instance,
                        hours=hours
                    )
                )
            ProjectFundedStaff.objects.bulk_create(
                project_funded_staff_list,
                update_conflicts=True,
                update_fields=['hours'],
                unique_fields=['salary_level_id', 'start_id']
            )
        return self.instance