from django.urls import include, path
from django.utils.translation import gettext_lazy as _
from vkk.models import ProjectFundedStaffDate
from vkk.workhours.accounting.views import (
    AccountingSuccessView, AccountingUpdateView, AccountingDeleteView,
)
from .views import ProjectFundedStaffListView, ProjectFundedStaffCreateView
from .forms import ProjectFundedStaffForm

model = {'model': ProjectFundedStaffDate}

app_name='funded_staff'
urlpatterns = [
    path(
        _('create/'),
        ProjectFundedStaffCreateView.as_view(),
        name='create'
    ),
    path(
        _('create/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/create_success.html',
            **model
        ),
        name='create_success'
    ),
    path(
        _('<int:pk>/update/'),
        AccountingUpdateView.as_view(
            form_class=ProjectFundedStaffForm,
            **model
        ),
        name='update'
    ),
    path(
        _('update/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/update_success.html',
            **model
        ),
        name='update_success'
    ),
    path(
        _('<int:pk>/delete/'),
        AccountingDeleteView.as_view(**model),
        name='delete'
    ),
    path(
        _('delete/success/'),
        AccountingSuccessView.as_view(
            template_name='vkk/generic/delete_success.html',
            **model
        ),
        name='delete_success'
    ),
    path('', ProjectFundedStaffListView.as_view(), name='default'),
]
