from smtplib import SMTPException
from vkk.workhours.accounting.views import AccountingCreateView, AccountingDetailView
from vkk.users.models import User, NewUser, send_registration_mail
from vkk.workhours.models import ProjectAssignment, ProjectManager

class UserCreateView(AccountingCreateView):
    model = User
    fields = ['first_name', 'last_name', 'email']

    def form_valid(self, form):
        user = form.instance
        user.set_unusable_password()
        response = super().form_valid(form)
        try:
            send_registration_mail(user)
        except SMTPException:
            user.delete()
            raise
        return response

class AccountingUserDetailView(AccountingDetailView):
    template_name = 'vkk/workhours/accounting/users/details.html'
    model = User
    fields = ['first_name', 'last_name', 'email', 'last_login', 'is_accountant', 'is_active']

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        manages = ProjectManager.objects.filter(
            manager__pk=self.kwargs['pk']
        ).select_related('project').order_by('project__invoice_number')
        assignments = ProjectAssignment.objects.filter(
            contributor__pk=self.kwargs['pk']
        ).select_related('project').order_by('project__invoice_number')
        context['manages'] = manages
        context['assignments'] = assignments
        return context
