from vkk.users.models import User
from django.contrib.auth.mixins import AccessMixin
from django.utils import timezone
from ..models import ProjectManager

class ProjectManagerRequiredMixin(AccessMixin):
    """Verify that the current user is a manager of at least one project."""
    check_field = None

    def dispatch(self, request, *args, **kwargs):
        project_manager = ProjectManager.objects.filter(
            manager=request.user,
            end__gte=timezone.now().date(),
        )
        in_charge = True
        if 'pk' in self.kwargs:
            in_charge = User.objects.filter(
                pk=self.kwargs['pk'],
                projectassignment__project__projectmanager__manager=self.request.user,
            ).exists()
        if ( not request.user.is_authenticated or
        not project_manager.exists() or not in_charge ):
            return self.handle_no_permission()
        return super().dispatch(request, *args, **kwargs)
