from django.contrib.auth.mixins import AccessMixin
from django.utils import timezone
from django.db.models import Q
from vkk.workhours.models import ProjectAssignment, Period
from vkk.workhours.forms import PeriodSelectForm

class ContributorRequiredMixin(AccessMixin):
    """Verify that the current user is a contributor to the given project."""
    def dispatch(self, request, *args, **kwargs):
        assignment_query = ProjectAssignment.objects.filter(
            pk=kwargs.get('assignment_pk')
        )
        if not request.user.is_authenticated or not assignment_query.exists():
            return self.handle_no_permission()
        return super().dispatch(request, *args, **kwargs)

class ContributorPeriodSelectorMixin():
    """Adds a Form for selecting Periods."""
    def get_context_data(self, **kwargs):
        now = timezone.now()
        query_set = Period.objects.filter(
            Q(dead_line__gte=now) | 
            Q(workhours__project_assignment__pk=self.kwargs['assignment_pk']) |
            Q(periodclosure__project_assignment__pk=self.kwargs['assignment_pk'])
        ).distinct()
        context = super().get_context_data(**kwargs)
        context['period_selector'] = PeriodSelectForm(
            queryset=query_set.order_by('-start'),
            initial={'period': self.kwargs['period_pk']}
        )
        return context