#! /bin/sh

mkdir ./nginx/ssl

echo "REVERSE-PROXY: Create a RSA key"
openssl genrsa -out ./nginx/ssl/client.key 4096

echo "REVERSE-PROXY: Create a Certificate Signing Request (CSR)"
openssl req -new -sha256 -subj "/CN=vkk" -key ./nginx/ssl/client.key -out ./nginx/ssl/cert.csr

echo "REVERSE-PROXY: Create a extfile with all the alternative names"
echo "subjectAltName=DNS:nginx" > ./nginx/ssl/extfile.cnf
echo "extendedKeyUsage=clientAuth" >> ./nginx/ssl/extfile.cnf

echo "REVERSE-PROXY: Create the certificate"
openssl x509 -req -sha256 -days 3650 -passin env:PASSPHRASE -in ./nginx/ssl/cert.csr -CA ./scripts/ca/ca.pem -CAkey ./scripts/ca/ca-key.pem -out ./nginx/ssl/client.pem -extfile ./nginx/ssl/extfile.cnf -CAcreateserial

echo "REVERSE-PROXY: Cleanup"
rm ./nginx/ssl/cert.csr
rm ./nginx/ssl/extfile.cnf
cp ./scripts/ca/ca.pem ./nginx/ssl/trusted_ca_cert.crt